@@ -1,7 +1,8 @@
 """Console script for qnorm."""
 import argparse
 import sys
-import warnings
+
+from .util import get_delim
 
 try:
     import pandas as pd
@@ -29,16 +30,12 @@ def main():
     )
     args = parser.parse_args()
 
-    with warnings.catch_warnings():
-        warnings.simplefilter("ignore")
-        inferred_sep = pd.read_csv(
-            args.table, sep=None, iterator=True
-        )._engine.data.dialect.delimiter
+    delimiter = get_delim(args.table)
 
-    df = pd.read_csv(args.table, index_col=0, sep=inferred_sep, comment="#")
+    df = pd.read_csv(args.table, index_col=0, sep=delimiter, comment="#")
     qnorm_df = qnorm.quantile_normalize(df)
 
-    print(qnorm_df.to_csv(sep=inferred_sep))
+    print(qnorm_df.to_csv(sep=delimiter))
 
 
 if __name__ == "__main__":
